==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/DataLegendSeriesValueInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
/**
 * @hidden
 */
var DataLegendSeriesValueInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataLegendSeriesValueInfo, _super);
    function DataLegendSeriesValueInfo() {
        var _this = _super.call(this) || this;
        _this.l = 0;
        _this.t = null;
        _this.u = null;
        _this.v = null;
        _this.w = null;
        _this.x = null;
        _this.n = 0;
        _this.m = 0;
        _this.j = false;
        _this.i = false;
        _this.e = false;
        _this.h = false;
        _this.f = false;
        _this.g = false;
        _this.d = false;
        _this.a = 0;
        _this.o = 0;
        _this.k = false;
        _this.c = false;
        _this.b = false;
        _this.p = null;
        _this.q = null;
        _this.r = null;
        _this.b = true;
        _this.c = true;
        _this.k = false;
        _this.t = "";
        _this.u = "";
        _this.v = "";
        _this.w = "";
        _this.q = "";
        _this.n = -1;
        _this.m = -1;
        _this.j = false;
        _this.i = false;
        _this.e = true;
        _this.h = true;
        _this.f = true;
        _this.g = true;
        _this.d = true;
        _this.x = null;
        return _this;
    }
    DataLegendSeriesValueInfo.prototype.s = function () {
        return this.p + ": " + this.l;
    };
    DataLegendSeriesValueInfo.$t = markType(DataLegendSeriesValueInfo, 'DataLegendSeriesValueInfo');
    return DataLegendSeriesValueInfo;
}(Base));
export { DataLegendSeriesValueInfo };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/DataLegendSeriesValueInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { stringIsNullOrEmpty } from "./string";
/**
 * @hidden
 */
var DataLegendSeriesValueInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataLegendSeriesValueInfo, _super);
    function DataLegendSeriesValueInfo() {
        var _this = _super.call(this) || this;
        _this.l = 0;
        _this.u = null;
        _this.v = null;
        _this.w = null;
        _this.x = null;
        _this.y = null;
        _this.n = 0;
        _this.m = 0;
        _this.j = false;
        _this.i = false;
        _this.e = false;
        _this.h = false;
        _this.f = false;
        _this.g = false;
        _this.d = false;
        _this.a = 0;
        _this.o = 0;
        _this.k = false;
        _this.c = false;
        _this.b = false;
        _this.q = null;
        _this.p = null;
        _this.r = null;
        _this.s = null;
        _this.b = true;
        _this.c = true;
        _this.k = false;
        _this.u = "";
        _this.v = "";
        _this.w = "";
        _this.x = "";
        _this.r = "";
        _this.n = -1;
        _this.m = -1;
        _this.j = false;
        _this.i = false;
        _this.e = true;
        _this.h = true;
        _this.f = true;
        _this.g = true;
        _this.d = true;
        _this.y = null;
        return _this;
    }
    DataLegendSeriesValueInfo.prototype.t = function () {
        var a = "";
        if (!stringIsNullOrEmpty(this.q)) {
            a += this.q + ": ";
        }
        else if (!stringIsNullOrEmpty(this.p)) {
            a += this.p + ": ";
        }
        a += this.l;
        return a;
    };
    DataLegendSeriesValueInfo.$t = markType(DataLegendSeriesValueInfo, 'DataLegendSeriesValueInfo');
    return DataLegendSeriesValueInfo;
}(Base));
export { DataLegendSeriesValueInfo };
